summaryrefslogtreecommitdiffstats
path: root/src/main/java/net/minecraft
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/net/minecraft')
-rw-r--r--src/main/java/net/minecraft/server/EntityHuman.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/main/java/net/minecraft/server/EntityHuman.java b/src/main/java/net/minecraft/server/EntityHuman.java
index 5c29744a..c552f000 100644
--- a/src/main/java/net/minecraft/server/EntityHuman.java
+++ b/src/main/java/net/minecraft/server/EntityHuman.java
@@ -685,9 +685,10 @@ public abstract class EntityHuman extends EntityLiving {
ItemStack itemstack = this.U();
if (itemstack != null && entity instanceof EntityLiving) {
+ if (this.abilities.canInstantlyBuild) itemstack = itemstack.cloneItemStack(); // CraftBukkit - if the player can instantly build, don't decrement the stack.
itemstack.a((EntityLiving) entity);
- // CraftBukkit - bypass infinite items; <= 0 -> == 0
- if (itemstack.count == 0) {
+ // CraftBukkit - bypass infinite items; <= 0 -> == 0, only remove items if not able to instantly build
+ if (itemstack.count == 0 && !this.abilities.canInstantlyBuild) {
itemstack.a(this);
this.V();
}